Skip to main contentModule backtracking
Source - nqueens
- The n-queens puzzle is the problem of placing n queens on an n x n chessboard such that no two queens attack each other.
- sudoku
- Write a program to solve a Sudoku puzzle by filling the empty cells.